using System;
using System.Data;
using System.Collections.Generic;
using ZXDT.CallCenter.Model;
namespace ZXDT.CallCenter.BLL
{
    /// <summary>
    /// T_Good_Info
    /// </summary>
    public partial class T_Good_Info
    {
        private readonly ZXDT.CallCenter.DAL.T_Good_Info dal = new ZXDT.CallCenter.DAL.T_Good_Info();
        public T_Good_Info()
        { }
        #region  BasicMethod



        /// <summary>
        /// 增加一条数据
        /// </summary>
        public int Add(ZXDT.CallCenter.Model.T_Good_Info model)
        {
            return dal.Add(model);
        }

        /// <summary>
        /// 更新一条数据
        /// </summary>
        public bool Update(ZXDT.CallCenter.Model.T_Good_Info model)
        {
            return dal.Update(model);
        }

        /// <summary>
        /// 删除一条数据
        /// </summary>
        public bool Delete(int id)
        {

            return dal.Delete(id);
        }
        /// <summary>
        /// 删除一条数据
        /// </summary>
        public bool DeleteList(string idlist)
        {
            return dal.DeleteList(idlist);
        }

        /// <summary>
        /// 得到一个对象实体
        /// </summary>
        public ZXDT.CallCenter.Model.T_Good_Info GetModel(int id)
        {

            return dal.GetModel(id);
        }



        /// <summary>
        /// 获得数据列表
        /// </summary>
        public DataSet GetList(string strWhere)
        {
            return dal.GetList(strWhere);
        }

        /// <summary>
        /// 归还
        /// </summary>
        public bool RebackGoods(ZXDT.CallCenter.Model.T_Good_Info model)
        {
            return dal.RebackGoods(model);
        }

        #endregion  BasicMethod
        #region  失物转移发起

        public bool TransferGoodList(Model.T_Good_TransInfo model)
        {
            return dal.TransferGoodList(model);
        }

        #endregion


        #region  失物接收/退回

        public bool TransferGoodReceivedList(Model.T_Good_TransInfo model, int status)
        {
            return dal.TransferGoodReceivedList(model, status);
        }

        #endregion

     
        #region 销毁
        /// <summary>
        /// 删除
        /// </summary>
        /// <param name="idList"></param>
        /// <returns></returns>
        public bool AdminDeleteGoods(string idList)
        {
            return dal.AdminDeleteGoods(idList);
        }
        /// <summary>
        /// 销毁
        /// </summary>
        public bool DeleteGoods(string idList)
        {
            return dal.DeleteGoods(idList);
        }


        /// <summary>
        /// 自动销毁
        /// </summary>
        public void DeleteGoodsBySys()
        {
            dal.DeleteGoodsBySys();
        }
        #endregion
    }
}

